@@ -17,8 +17,8 @@
 #
 # This translation was last checked for Oddmuse version 1.504.
 #
-$ModulesDescription .= '<p>$Id: chinese-utf8.pl,v 1.3 2005/07/02 00:03:28 as Exp $</p>';
-%Translate = split('\n',<<END_OF_TRANSLATION);
+$ModulesDescription .= '<p>$Id: chinese-utf8.pl,v 1.6 2005/10/09 12:48:35 as Exp $</p>';
+%Translate = split(/\n/,<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 禁止讀取：使用者、ip 或是網路已被禁止連線。
 Could not create %s
@@ -105,6 +105,10 @@ List later changes
 列出最新的修改
 Filters
 過濾器
+Title:
+
+Title and Body:
+
 Username:
 使用者名稱：
 Host:
@@ -121,6 +125,8 @@ new
 新增
 from %s
 自 %s
+This page is too big to send over RSS.
+
 History of %s
 %s 的歷史記錄
 Compare
@@ -145,8 +151,6 @@ Wiki Version
 顯示 Wiki 的版本
 Unlock Wiki
 解鎖
-Recent Visitors
-最近的參訪者
 Password
 密碼
 Run maintenance
@@ -155,6 +159,8 @@ Unlock site
 網站解鎖
 Lock site
 網站鎖定
+Install CSS
+
 Unlock %s
 
 Lock %s
@@ -239,6 +245,8 @@ minor
 次要
 No diff available.
 沒有差異。
+The two revisions are the same.
+
 Old revision:
 舊版本：
 Changed:
@@ -287,7 +295,7 @@ No unlock required.
 1 秒前
 just now
 就是現在
-Editing Denied
+Edit Denied
 禁止編輯
 Editing not allowed: user, ip, or network is blocked.
 禁止編輯；使用者、ip 或是網路已被禁止連線。
@@ -355,6 +363,8 @@ Include near pages
 
 (for %s)
 (列出 %s )
+Filter:
+
 %s pages found.
 找到 %s 個頁面。
 Replaced: %s
@@ -399,10 +409,10 @@ Browser reports no file info.
 瀏覽器沒有提供檔案資料。
 Browser reports no file type.
 瀏覽器沒有提供檔案型態。
-Edit Denied
-禁止編輯
 The page contains banned text.
 本頁含有一些禁止出現的文字。
+No changes to be saved.
+
 This page was changed by somebody else %s.
 本頁在 %s 已被人修改過。
 The changes conflict.  Please check the page again.
@@ -485,6 +495,8 @@ Click to search for references to this permanent anchor
 按下即可搜尋此錨點的相關資料
 the page %s also exists
 也存在一個叫 %s 的頁面
+Copy one of the following stylesheets to %s:
+
 Deleting %s
 正在刪除 %s
 Deleted %s
@@ -509,6 +521,14 @@ Rename %s to:
 
 Cannot highlight the language %s.
 無法強調顯示 %s 。
+Recent Visitors
+最近的參訪者
+some action
+
+was here
+
+and read
+
 Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.
 缺少下列之一的工具以致無法產生日曆: cal(1), Date::Calc(3), 或 Date::Pcalc(3)
 The match parameter is missing.
@@ -543,10 +563,18 @@ Marked as %s.
 標記為 %s 。
 Cannot find unspammed revision.
 找不到未被 spam 的版本。
+Add Comment
+
+ordinary changes
+
 Footnotes:
 註解：
 Could not find %1.html template in %2
 無法在 %2 找到 %1.html 的範本
+Only Editors are allowed to see hidden pages.
+
+Only Admins are allowed to see hidden pages.
+
 image: %s
 圖像: %s
 Index
@@ -579,6 +607,10 @@ Your registration for %s has been submitted.
 
   Please allow time for the webmaster to approve your request.
 
+  An email has been sent to "%s" with further instructions.
+
+There was an error saving your registration.
+
 An account was created for %s.
 
 Login to %s
@@ -589,7 +621,7 @@ Logged in as %s.
 
 Logout of %s
 
-Logout of %s?
+<p>Logout of %s?</p>
 
 Logged out of %s
 
@@ -601,6 +633,60 @@ Login
 
 Logout
 
+Who am I?
+
+Forgot your password?
+
+Change your password
+
+Approve pending registrations
+
+Confirm Registration for %s
+
+%s, your registration has been approved. You can now use your password to login and edit this wiki.
+
+Confirmation failed.  Please email %s for help.
+
+Who Am I?
+
+You are logged in as %s.
+
+You are not logged in.
+
+Reset Password
+
+The password for %s was reset.  It has been emailed to the address on file.
+
+There was an error resetting the password for %s
+
+The username "%s" does not exist.
+
+Reset Password for %s
+
+<p>Reset Password?</p>
+
+Change Password for %s
+
+<p>Change Password?</p>
+
+Your current password is incorrect.
+
+Your password has been changed.
+
+Approve Pending Registrations for %s
+
+%s has been approved.
+
+There was an error approving %s.
+
+<ul>
+
+<li>%1 - %2</li>
+
+</ul>
+
+There are no pending registrations.
+
 Clearing Cache
 清除暫存
 Done.
@@ -619,6 +705,10 @@ Local Map for %s
 
 view
 
+Self-ban by %s
+
+You have banned your own IP.
+
 Orphan List
 孤立頁面列表
 Trail: 
@@ -659,6 +749,10 @@ Static Copy
 靜態頁面備份
 Back to %s
 返回 %s
+Copy to %1 succeeded: %2.
+
+Copy to %1 failed: %2.
+
 Tag
 
 Alternatively, use one of the following templates:
@@ -695,7 +789,7 @@ The translation is outdated.
 本頁翻譯已過期。
 The page does not exist.
 頁面不存在。
-http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s
+http://search.barnesandnoble.com/booksearch/isbninquiry.asp?ISBN=%s
 
 http://www.amazon.com/exec/obidos/ISBN=%s
 
@@ -705,6 +799,14 @@ http://www.pricescan.com/books/BookDetail.asp?isbn=%s
 
 search
 搜尋
+Upload of %s file
+
 Blog
 
+Matching pages:
+
+New
+
+Edit %s.
+
 END_OF_TRANSLATION
