@@ -16,7 +16,14 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: despam.pl,v 1.4 2004/11/26 17:10:10 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: despam.pl,v 1.6 2005/09/24 08:17:05 as Exp $</p>';
+
+push(@MyAdminCode, \&DespamMenu);
+
+sub DespamMenu {
+  my ($id, $menuref, $restref) = @_;
+  push(@$menuref, ScriptLink('action=despam', T('Despamming pages')));
+}
 
 $Action{despam} = \&DoDespam;
 
