@@ -16,7 +16,7 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: headers.pl,v 1.5 2004/10/19 23:39:01 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: headers.pl,v 1.12 2004/12/05 03:51:45 as Exp $</p>';
 
 push(@MyRules, \&HeadersRule);
 
@@ -35,13 +35,20 @@ push(@MyRules, \&HeadersRule);
 sub HeadersRule {
   my $oldpos = pos;
   if ($bol && (m/\G((.+?)[ \t]*\n(---+|===+)[ \t]*\n)/gc)) {
+    my $html = CloseHtmlEnvironments() . ($PortraitSupportColorDiv ? '</div>' : '');
     if (substr($3,0,1) eq '=') {
-      return CloseHtmlEnvironments() . "<h2>$2</h2>";
+      $html .= $q->h2($2);
     } else {
-      return CloseHtmlEnvironments() . "<h3>$2</h3>";
+      $html .= $q->h3($2);
     }
+    $PortraitSupportColorDiv = 0;
+    $PortraitSupportColor = 0;
+    return $html . AddHtmlEnvironment('p');
   } elsif ($bol && m/\G(\s*\n)*----+[ \t]*\n?/cg) {
-    return CloseHtmlEnvironments() . $q->hr();
+    my $html = CloseHtmlEnvironments() . ($PortraitSupportColorDiv ? '</div>' : '') . $q->hr();
+    $PortraitSupportColorDiv = 0;
+    $PortraitSupportColor = 0;
+    return $html . AddHtmlEnvironment('p');
   }
   return undef;
 }
