@@ -20,11 +20,7 @@ use vars qw($PageTrailLength);
 
 $PageTrailLength = 10;
 
-$ModulesDescription .= '<p>$Id: page-trail.pl,v 1.4 2004/10/12 22:03:36 as Exp $</p>';
-
-$DefaultStyleSheet .= <<'EOT' unless $DefaultStyleSheet =~ /span\.trail/; # mod_perl?
-@media print { span.trail { display: none; }}
-EOT
+$ModulesDescription .= '<p>$Id: page-trail.pl,v 1.5 2005/10/09 00:55:43 as Exp $</p>';
 
 $CookieParameters{trail} = '';
 $InvisibleCookieParameters{trail} = 1;
