@@ -16,17 +16,10 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: referrer-tracking.pl,v 1.2 2005/01/07 00:54:29 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: referrer-tracking.pl,v 1.4 2005/10/09 00:55:43 as Exp $</p>';
 
 ## == Setup ==
 
-$DefaultStyleSheet .= q{
-div.refer { padding-left:5%; padding-right:5%; font-size:smaller; }
-@media print {
-  div.refer { display:none; }
-}
-} unless $DefaultStyleSheet =~ /div\.refer/; # mod_perl?
-
 push(@KnownLocks, "refer_*");
 
 $Action{refer} = \&DoPrintAllReferers;
@@ -160,6 +153,7 @@ sub WriteReferers {
 
 sub RefererTrack {
   my $id = shift;
+  return unless $id;
   ReadReferers($id);
   WriteReferers($id) if UpdateReferers($id);
   return GetReferers();
